<?php 

class wc_wannme extends WC_Payment_Gateway {
	
    private $order_status;
	
	private static $payment_gateways = array(
		'wc_wannme',
		'wc_wannme_cards',
        'wc_wannme_bizum',
		'wc_wannme_floapay',
        'wc_wannme_banktransfer',
		'wc_wannme_sepadd',
        'wc_wannme_paypal',
    );		
	
	/**
	 * Plugin initialization.
	 */
	public function init() {

		$this->define_constants();
		$this->include_payment_methods();
				
	}

	private function define_constants() {
		define( 'WANNME_URL_DEV', 'https://rest-demo.wannme.com/integration/v2' );
		define( 'WANNME_URL_PROD', 'https://rest.wannme.com/integration/v2' );
		define( 'WANNME_ENV',$this->get_option('WANNME_ENV'));
		define( 'WANNME_PARTNERID',$this->get_option('WANNME_PARTNERID'));
		define( 'WANNME_PRIVATEKEY',$this->get_option('WANNME_PRIVATEKEY'));
		define( 'WANNME_SECRETKEY',$this->get_option('WANNME_SECRETKEY'));
		define( 'WANNME_DIRECT_LINKS',$this->get_option('WANNME_DIRECT_LINKS'));
		define( 'WANNME_TYPES_PAYIN7',$this->get_option('WANNME_TYPES_PAYIN7'));
		define( 'WANNME_TYPES_FLOAPAY',$this->get_option('WANNME_TYPES_FLOAPAY'));
		define( 'WANNME_TYPES_REDSYS',$this->get_option('WANNME_TYPES_REDSYS'));
		define( 'WANNME_TYPES_CECABANK',$this->get_option('WANNME_TYPES_CECABANK'));
		define( 'WANNME_TYPES_BIZUM',$this->get_option('WANNME_TYPES_BIZUM'));
		define( 'WANNME_TYPES_SLIMPAY_DIRECT_DEBIT',$this->get_option('WANNME_TYPES_SLIMPAY_DIRECT_DEBIT'));
		define( 'WANNME_TYPES_BANKTRANSFER',$this->get_option('WANNME_TYPES_BANKTRANSFER'));
		define( 'WANNME_TYPES_AFTERBANKS',$this->get_option('WANNME_TYPES_AFTERBANKS'));
		define( 'WANNME_TYPES_YAPILY',$this->get_option('WANNME_TYPES_YAPILY'));
		define( 'WANNME_TYPES_PAYPAL',$this->get_option('WANNME_TYPES_PAYPAL'));
		define( 'WANNME_MANUALPAYMENT',$this->get_option('WANNME_MANUALPAYMENT'));
		define( 'WANNME_SENDEMAIL',$this->get_option('WANNME_SENDEMAIL'));
		define( 'WANNME_SENDSMS',$this->get_option('WANNME_SENDSMS'));
		define( 'WANNME_OPTIONS_REF1',$this->get_option('WANNME_OPTIONS_REF1'));
		define( 'WANNME_OPTIONS_REF2',$this->get_option('WANNME_OPTIONS_REF2'));
	}	

	public function __construct()
	{
		$this->id = 'wc_wannme';
		$this->method_title = __('WANNME Payment Gateway', 'wc-wannme' );
		$this->method_description = __('Offer different payment methods or increase your sales by offering financing to your clients', 'wc-wannme' );
				
		$this->has_fields = false;
		$this->log =  new WC_Logger();
		
		$this->supports = array(
			'products'
		);
		
		$this->init_form_fields();
		$this->init_settings();
		$this->init();
		
		$this->enabled = $this->get_option('enabled');
		$this->title = $this->get_option('title');
		$this->description = $this->get_option('description');
		$this->hide_text_box = $this->get_option('hide_text_box');

		$this->url = (WANNME_ENV == 0) ? WANNME_URL_DEV:WANNME_URL_PROD;

		if (defined( 'WANNME_DIRECT_LINKS' ) && WANNME_DIRECT_LINKS == 'no') {
			$this->icon = add_filter( 'woocommerce_gateway_icon', array($this, 'get_logos'),10,2);
		}


        add_filter('woocommerce_available_payment_gateways', array($this, 'wannme_update_payment_methods'));
		add_action('woocommerce_update_options_payment_gateways_'.$this->id, array($this, 'process_admin_options'));

		//Payment listener/API hook
        add_action( 'woocommerce_api_wc_wannme', array( $this, 'updateWnOrder' ) );
		
		add_action( 'wp_enqueue_scripts', array( $this, 'add_scripts' ) );
	}
	

	public function init_form_fields()
	{
		$this->form_fields = array(
			'enabled' => array(
				'title' 		=> __( 'Enable/Disable', 'wc-wannme' ),
				'type' 			=> 'checkbox',
				'label' 		=> __( 'Enable WANNME Payment', 'wc-wannme' ),
				'default' 		=> 'yes'
			),
            'title' => array(
				'title' 		=> __( 'Method Title', 'wc-wannme' ),
				'type' 			=> 'text',
				'description' 	=> __( 'This controls the title', 'wc-wannme' ),
				'default'		=> __( 'WANNME Payment Gateway', 'wc-wannme' ),
				'description' 	=> __( 'This text will be showed in the payment options. Please describe something user friendly (example: "Instant financing", "Pay or finance with WANNME").', 'wc-wannme' ),
				'desc_tip'		=> false,
			),
			'description' => array(
				'title' => __( 'Customer Message', 'wc-wannme' ),
				'type' => 'textarea',
				'css' => 'width:500px;',
				'default' => '',
				'description' 	=> __( 'The message which you want it to appear to the customer in the checkout page.', 'wc-wannme' ),
			),
			/*'hide_text_box' => array(
				'title' 		=> __( 'Hide The Payment Field', 'wc-wannme' ),
				'type' 			=> 'checkbox',
				'label' 		=> __( 'Hide', 'wc-wannme' ),
				'default' 		=> 'no',
				'description' 	=> __( 'If you do not need to show the text box for customers at all, enable this option.', 'wc-wannme' ),
			),*/
			'WANNME_ENV' => array(
                'title'       => __( 'Select a enviroment', 'wc-wannme' ),
                'type'        => 'select',
                'default'     => 0,
                'desc_tip'    => true,
                'options'     => array(
                        0 => __( 'Test', 'wc-wannme' ),
                        1 => __( 'Production', 'wc-wannme' )
                )
        	),
			'API_CREDENTIALS'   => array(
				'title'       => __( 'API Credentials', 'wc-wannme' ),
				'type'        => 'title',
				'description' => __( 'Get your API credentials from WANNME.', 'wc-wannme' ),
			),
        	'WANNME_PARTNERID' => array(
				'title' 		=> __( 'Partner ID', 'wc-wannme' ),
				'type' 			=> 'text',
				'description' 	=> __( 'Enter a valid Partner ID', 'wc-wannme' ),
				'desc_tip'		=> true,
			),
			'WANNME_PRIVATEKEY' => array(
				'title' 		=> __( 'Private Key', 'wc-wannme' ),
				'type' 			=> 'text',
				'description' 	=> __( 'Enter a valid Private Key', 'wc-wannme' ),
				'desc_tip'		=> true,
			),
			'WANNME_SECRETKEY' => array(
				'title' 		=> __( 'Secret Key', 'wc-wannme' ),
				'type' 			=> 'text',
				'description' 	=> __( 'Enter a valid Secret Key', 'wc-wannme' ),
				'desc_tip'		=> true
			),
			'PAYMENT_METHODS'   => array(
				'title'       => __( 'Payment Methods', 'wc-wannme' ),
				'type'        => 'title',
				'description' => __( 'The selected methods will be showed to your customers in the WANNME checkout page. If you select none then all of the active methods in WANNME will be showed. Selected methods must be previously activated in WANNME.', 'wc-wannme' ),
			),
			'WANNME_DIRECT_LINKS' => array(
				'title' 		=> __( 'Enable/Disable DirectLinks', 'wc-wannme' ),
				'type' 			=> 'checkbox',
				'default' 		=> 'no',
				'label' 		=> __( 'When this option is enabled, payment methods will be shown in WooCommerce checkout, before redirecting to Wannme', 'wc-wannme' ),
				'description' 	=> __( 'When this option is enabled, payment methods will be shown in WooCommerce checkout, before redirecting to Wannme', 'wc-wannme' ),
				'desc_tip'		=> true
			),
			'WANNME_TYPES_FLOAPAY' => array(
				'title' 		=> __( 'Enable/Disable FloaPay', 'wc-wannme' ),
				'type' 			=> 'checkbox',
				'default' 		=> 'no',
				'label' 		=> __( 'FloaPay (Pay in 3 or 4 installments)', 'wc-wannme' ),
				'desc_tip'		=> true
			),
			'WANNME_TYPES_REDSYS' => array(
				'title' 		=> __( 'Enable/Disable Card Payment', 'wc-wannme' ),
				'type' 			=> 'checkbox',
				'label' 		=> __( 'Card Payment (Visa/Mastercard)', 'wc-wannme' ),
				'default' 		=> 'no',
				'desc_tip'		=> true
			),
			'WANNME_TYPES_BIZUM' => array(
				'title' 		=> __( 'Enable/Disable Bizum', 'wc-wannme' ),
				'type' 			=> 'checkbox',
				'label' 		=> __( 'Bizum', 'wc-wannme' ),
				'default' 		=> 'no',
				'desc_tip'		=> true
			),
			'WANNME_TYPES_SLIMPAY_DIRECT_DEBIT' => array(
				'title' 		=> __( 'Enable/Disable Direct Debit', 'wc-wannme' ),
				'type' 			=> 'checkbox',
				'label' 		=> __( 'Direct Debit (SEPA)', 'wc-wannme' ),
				'default' 		=> 'no',
				'desc_tip'		=> true
			),
			'WANNME_TYPES_BANKTRANSFER' => array(
				'title' 		=> __( 'Enable/Disable Transfer', 'wc-wannme' ),
				'type' 			=> 'checkbox',
				'label' 		=> __( 'Bank Transfer', 'wc-wannme' ),
				'default' 		=> 'no',
				'desc_tip'		=> true
			),
			'WANNME_TYPES_PAYPAL' => array(
				'title' 		=> __( 'Enable/Disable Paypal', 'wc-wannme' ),
				'type' 			=> 'checkbox',
				'label' 		=> __( 'Paypal', 'wc-wannme' ),
				'default' 		=> 'no',
				'desc_tip'		=> true
			),
			'WANNME_OPTIONS'   => array(
				'title'       => __( 'Options', 'wc-wannme' ),
				'type'        => 'title',
				'description' => __( 'Configuration options', 'wc-wannme' ),
			),
			'WANNME_OPTIONS_REF1' => array(
				'title' 		=> __( 'Reference1 Prefix', 'wc-wannme' ),
				'type' 			=> 'text',
				'description' 	=> __( 'This prefix text will be added to the External Reference1 field when creating the payment in your Wannme account.', 'wc-wannme' ),
				'desc_tip'		=> true
			),
			'WANNME_OPTIONS_REF2' => array(
				'title' 		=> __( 'Reference2 Prefix', 'wc-wannme' ),
				'type' 			=> 'text',
				'description' 	=> __( 'This prefix text will be added to the External Reference2 field when creating the payment in your Wannme account.', 'wc-wannme' ),
				'desc_tip'		=> true
			)
			/*,
			'WANNME_MANUALPAYMENT' => array(
				'title' 		=> __( 'Enable/Disable', 'wc-wannme' ),
				'type' 			=> 'checkbox',
				'label' 		=> __( 'Manual Payment', 'wc-wannme' ),
				'default' 		=> 'false',
				'description' 	=> __( 'The manualPayment parameter configures manual payment. If manualPayment is set to true, no SMS or email will be sent, if it is set to false the sendSMS and sendEmail parameters will be used as provided', 'wc-wannme' ),
				'desc_tip'		=> true
			),
			'WANNME_SENDEMAIL' => array(
				'title' 		=> __( 'Enable/Disable', 'wc-wannme' ),
				'type' 			=> 'checkbox',
				'label' 		=> __( 'Send Email', 'wc-wannme' ),
				'default' 		=> 'true'
			),
			'WANNME_SENDSMS' => array(
				'title' 		=> __( 'Enable/Disable', 'wc-wannme' ),
				'type' 			=> 'checkbox',
				'label' 		=> __( 'Send SMS', 'wc-wannme' ),
				'default' 		=> 'true'
			)*/
		);
	}
	
	public function get_logos() {
		$icon_html = '';
		$icon_html = '<ul class="wc-logos">';
		if (defined( 'WANNME_TYPES_REDSYS' ) && WANNME_TYPES_REDSYS == 'yes') {
			$icon_html .= '<li class="wc-payment-method-logo">';
			$icon_html .= '<img src="' . esc_url( plugins_url( '/assets/images/cards.png', __FILE__) ) . '" alt="" />';
			$icon_html .= '</li>';
		}
		if (defined( 'WANNME_TYPES_BIZUM' ) && WANNME_TYPES_BIZUM == 'yes') {
			$icon_html .= '<li class="wc-payment-method-logo">';
			$icon_html .= '<img src="' . esc_url( plugins_url( '/assets/images/bizum.png', __FILE__) ) . '" alt="" />';
			$icon_html .= '</li>';			
		}
		if (defined( 'WANNME_TYPES_FLOAPAY' ) && WANNME_TYPES_FLOAPAY == 'yes') {
			$icon_html .= '<li class="wc-payment-method-logo">';
			$icon_html .= '<img src="' . esc_url( plugins_url( '/assets/images/floapay.png', __FILE__) ) . '" alt="" />';
			$icon_html .= '</li>';
		}
		if (defined( 'WANNME_TYPES_BANKTRANSFER' ) && WANNME_TYPES_BANKTRANSFER == 'yes') {
			//$icon_html .= '<li class="wc-payment-method-logo">';
			//$icon_html .= '<img src="' . esc_url( plugins_url( '/assets/images/transfer.png', __FILE__) ) . '" alt="" />';
			//$icon_html .= '</li>';			
		}
		if (defined( 'WANNME_TYPES_SLIMPAY_DIRECT_DEBIT' ) && WANNME_TYPES_SLIMPAY_DIRECT_DEBIT == 'yes') {
			//$icon_html .= '<li class="wc-payment-method-logo">';
			//$icon_html .= '<img src="' . esc_url( plugins_url( '/assets/images/sepadd.png', __FILE__) ) . '" alt="" />';
			//$icon_html .= '</li>';			
		}
		if (defined( 'WANNME_TYPES_PAYPAL' ) && WANNME_TYPES_PAYPAL == 'yes') {
			$icon_html .= '<li class="wc-payment-method-logo">';
			$icon_html .= '<img src="' . esc_url( plugins_url( '/assets/images/paypal.png', __FILE__) ) . '" alt="" />';
			$icon_html .= '</li>';			
		}		
		
		$icon_html .= '</ul>';
		
		return $icon_html;
	}
	
	public function add_scripts() {
        wp_enqueue_style('wc-wannme', plugins_url('/assets/css/wannme-styles.css', __FILE__), array());
	}	
	
	//Añadir opción de pago WANNME en Checkout
	public function wannme_update_payment_methods($available_gateways) {
		if (defined( 'WANNME_DIRECT_LINKS' ) && WANNME_DIRECT_LINKS == 'yes') {
			
			if (isset($available_gateways['wc_wannme'])) unset( $available_gateways['wc_wannme']);
			if (defined( 'WANNME_TYPES_REDSYS' ) && WANNME_TYPES_REDSYS == 'yes') $available_gateways[] = 'wc_wannme_cards';
			if (defined( 'WANNME_TYPES_BIZUM' ) && WANNME_TYPES_BIZUM == 'yes') $available_gateways[] = 'wc_wannme_bizum';
			if (defined( 'WANNME_TYPES_FLOAPAY' ) && WANNME_TYPES_FLOAPAY == 'yes') $available_gateways[] = 'wc_wannme_floapay';
			if (defined( 'WANNME_TYPES_BANKTRANSFER' ) && WANNME_TYPES_BANKTRANSFER == 'yes') $available_gateways[] = 'wc_wannme_banktransfer';
			if (defined( 'WANNME_TYPES_SLIMPAY_DIRECT_DEBIT' ) && WANNME_TYPES_SLIMPAY_DIRECT_DEBIT == 'yes') $available_gateways[] = 'wc_wannme_sepadd';
			if (defined( 'WANNME_TYPES_PAYPAL' ) && WANNME_TYPES_PAYPAL == 'yes') $available_gateways[] = 'wc_wannme_paypal';
			
		} 
		else {
			if (isset($available_gateways['wc_wannme_cards'])) unset( $available_gateways['wc_wannme_cards']);
			if (isset($available_gateways['wc_wannme_bizum'])) unset( $available_gateways['wc_wannme_bizum']);
			if (isset($available_gateways['wc_wannme_floapay'])) unset( $available_gateways['wc_wannme_floapay']);
			if (isset($available_gateways['wc_wannme_banktransfer'])) unset( $available_gateways['wc_wannme_banktransfer']);
			if (isset($available_gateways['wc_wannme_sepadd'])) unset( $available_gateways['wc_wannme_sepadd']);
			if (isset($available_gateways['wc_wannme_paypal'])) unset( $available_gateways['wc_wannme_paypal']);
			$available_gateways[] = 'wc_wannme';
		}
		
		return $available_gateways;
	}	
	
	public function checkVersion() {
		
		$this->log->add( 'wannme', 'cheking Version');	

		if (!empty(WANNME_SECRETKEY))
		{
			$options = array(
				CURLOPT_URL  => $this->url.'/ecommerce/system',
				CURLOPT_RETURNTRANSFER => true,
				CURLOPT_ENCODING       => "",
				CURLOPT_MAXREDIRS      => 10,
				CURLOPT_TIMEOUT        => 0,
				CURLOPT_FOLLOWLOCATION => true,
				CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
				CURLOPT_CUSTOMREQUEST  =>"GET",
				CURLOPT_HTTPHEADER => array(
					"Content-type: application/json; charset=UTF-8",
					"Authorization: ".WANNME_SECRETKEY
				)            
			);
			
			$ch = curl_init();
			curl_setopt_array( $ch, $options );
			if($result = json_decode(curl_exec( $ch )))
			{
				update_option('WANNME_LAST_VERSION', $result->ecommerce->wp->version);
				update_option('WANNME_URL_UPDATE', $result->ecommerce->wp->url);
			}
			//$result = json_decode(curl_exec( $ch ));
			curl_close( $ch );       
			
		}
	}	

	//Confirmación de pedido
	//1) Crear petición a WN
	//2) Ok -> Redir, Ko -> Error
	public function process_payment( $order_id, $direct_payment_method = null )
	{	
		global $woocommerce;
		$order = new WC_Order( $order_id );

		$wannme = $this->createPayment($order);

		if (!property_exists ($wannme, 'code'))
        {
			// Marcar pedido on-hold (esperando transacción)
			$order->update_status( 'pending', __( 'Awaiting WANNME payment', 'wc-wannme' ) );
			$order->save();

			// Comprobar direct links
			if (defined( 'WANNME_DIRECT_LINKS' ) && WANNME_DIRECT_LINKS == 'yes')
			{
				// Obtener direct link del método seleccionado
				$directLinks = json_decode($wannme->directlinks, true);
				foreach ($directLinks as $directLink)
				{
					if (in_array($directLink['paymentMethod'],$direct_payment_method))
						$directURL=$directLink['url'];
				}
				
				return array(
					'result' => 'success',
					'redirect' => $directURL
				);				
			}
			else
			{
				// Redireccionamos a enlace genérico
				return array(
					'result' => 'success',
					'redirect' => $wannme->url
				);
			}
        }
        else
        {
        	wc_add_notice(__( 'An error occured. Please contact the merchant to have more informations', 'wc-wannme' ), 'error' );
			$this->log->add( 'wannme', 'Error procesando el pago del pedido: '.$order_id);			
            return array('result' => 'error');
        }
	}	

	function updateWnOrder()
	{
        if (!empty( $_REQUEST ) && !empty( $_GET )) {

        	$id_order = $_GET["id_order"];
	        $action = $_GET["action"];

        	switch ($action) {
            	case 'update':
        			$order = new WC_Order($id_order);
	                $params = json_decode(file_get_contents("php://input"));
	                $payment_status = $this->getStatus((int) $params->statusCode);
	                $order->update_status($payment_status);
					if ($payment_status == 'processing') {
						wc_reduce_stock_levels( $id_order );
					}
	                $order->save();
	                WC()->cart->empty_cart();

	                //Actualizamos wmtracking
	                $wmtracking = $this->getWannmeByOrder($id_order);
                    $wmtracking->statusCode = (int) $params->statusCode;
                    $wmtracking->statusDescription = (string) $params->statusDescription;
                    $wmtracking->subStatusCode = (int) $params->subStatusCode;
                    $wmtracking->subStatusDescription = (string) $params->subStatusDescription;
                    $this->updateWannme((array) $wmtracking);

	                die('Order updated');
	                break;
        	}
        }
    }

    public function getStatus(Int $wm_status)
    {
    //	$states = array(
    //		1 => 'wm-os-create', //CREADO
	//		3 => 'wm-os-process', //EN PROCESO
	//		4 => 'wm-os-error', //ERROR
	//		5 => 'wm-os-completed', //PAGO COMPLETADO
	//		8 => 'wm-os-incomplete',
	//		9 => 'wm-os-cancelled', //CANCELADO
	//		10 => 'wm-os-expired', //PAGO CADUCADO
	//		13 => 'wm-os-refundtotal' //REEMBOLSO TOTAL
    //	);
		
    	$states = array(
    		1 => 'pending', //CREADO
    		2 => 'pending', //COMPARTIDO
			3 => 'pending', //EN PROCESO
			4 => 'failed', //ERROR
			5 => 'processing', //PAGO COMPLETADO
			7 => 'pending', //ACCEDIDO
			8 => 'failed', //PAGO INCOMPLETO
			9 => 'canceled', //CANCELADO
			10 => 'failed', //PAGO CADUCADO
			13 => 'refunded' //REEMBOLSO TOTAL
    	);		

        foreach ($states as $key => $value)
        {
            if ($key == $wm_status)
                return $value;
        }
    }

	public function createPayment(WC_Order $order)
	{
		
		global $wp_version;
		$firstName = $lastName1 = '';

		if ($order->has_billing_address() == true)
		{
			$firstName = $order->get_billing_first_name();
			$lastName1 = $order->get_billing_last_name();
		}
		
		$amount = (float) $order->get_total();
		$partnerReference1 = (WANNME_OPTIONS_REF1 == null ? WANNME_OPTIONS_REF1:WANNME_OPTIONS_REF1."-").$order->get_id();
		$partnerReference2 = WANNME_OPTIONS_REF2;

	    $data = array(
	        "amount" => $amount,
	        "checksum" => $this->getChecksum($amount, $partnerReference1),
	        "customer" => array(
	            "document" => '',
	            "documentType" => 0,
	            "firstName" => $firstName,
	            "lastName1" => $lastName1,
	            "lastName2" => ""
	        ),
	        "description" =>  __( 'Payment by', 'wc-wannme' ).' '.$firstName.' '.$lastName1,
	        "email" => $order->get_billing_email(),
	        "extra" => array(
	            "manualPayment" => (Bool) WANNME_MANUALPAYMENT,
	            "sendEmail" => (Bool) WANNME_SENDEMAIL,
	            "sendSMS" => (Bool) WANNME_SENDSMS
	        ),
	        "mobilePhone" => ($this->isPhoneNumber($order->get_billing_phone()) == true ? $order->get_billing_phone():null),
	        "notificationURL" => add_query_arg(array(
	        	'wc-api' => 'wc_wannme',
	        	'id_order' => $order->get_id(), 
	        	'action' => 'update'
	        ), home_url( '/' ) ),
	        "partnerId" => WANNME_PARTNERID,
	        "partnerReference1" => $partnerReference1,
	        "partnerReference2" => $partnerReference2,
	        "returnKOURL" => esc_url_raw( $order->get_cancel_order_url_raw() ),
	        "returnOKURL" => esc_url_raw( add_query_arg( 'utm_nooverride', '1', $this->get_return_url( $order ) ) ),
	        "paymentMethods" => $this->getPaymentMethods()
	    );

	    $options = array(
	        CURLOPT_URL  => $this->url.'/wannmepay/payment/',
	        CURLOPT_RETURNTRANSFER => true,
	        CURLOPT_ENCODING       => "",
	        CURLOPT_MAXREDIRS      => 10,
	        CURLOPT_TIMEOUT        => 0,
	        CURLOPT_FOLLOWLOCATION => true,
	        CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
	        CURLOPT_CUSTOMREQUEST  =>"POST",
	        CURLOPT_POSTFIELDS => json_encode($data),            
	        CURLOPT_HTTPHEADER => array(
	            "Content-type: application/json; charset=UTF-8",
	            "Authorization: ".WANNME_SECRETKEY,
	            "Wannme-Integration-Version: WordPress ".$wp_version." - WANNME ".get_option('WANNME_VERSION')
	        )            
	    );
			    
	    $ch = curl_init();
	    curl_setopt_array( $ch, $options );
	    $result = json_decode(curl_exec( $ch ));
	    $response = curl_getinfo( $ch );
	    curl_close( $ch );
		
	    $data = array(
		    'id_cart' => $order->get_id(),
		    'result' => json_encode($result)
		);

	    if (!property_exists ($result, 'code') || (int) json_encode($response['http_code']) < 200)
	    {
		    $data['id_tracking'] = $result->id;
		    $data['amount'] = $result->amount;
		    $data['description'] = $result->description;
		    $data['phone'] = $result->mobilePhone;
		    $data['email'] = $result->email;
		    $data['reference1'] = $result->partnerReference1;
		    $data['reference2'] = $result->partnerReference2;
		    $data['document'] = $result->customer->document;
		    $data['name'] = $result->customer->firstName;
		    $data['lastname'] = $result->customer->lastName1;
		    $data['manualPayment'] = $result->extra->manualPayment;
		    $data['sendEmail'] = $result->extra->sendSMS;
		    $data['sendSMS'] = $result->extra->sendEmail;
		    $data['url'] = $result->url;
		    $data['directlinks'] = json_encode($result->directLinks);
		    $data['imageQR'] = $result->imageQR;
		    $data['transactionCode'] = $result->transactionCode;
		    $data['statusCode'] = $result->statusCode;
		    $data['statusDescription'] = $result->statusDescription;
		    $data['subStatusCode'] = $result->subStatusCode;
		    $data['subStatusDescription'] = $result->subStatusDescription;
			$this->log->add( 'wannme', 'Cobro creado en WANNME correctamente. ID: '.$result->id);
	    }
	    else
	    {
		    $data['error'] = $result->code;
		    $data['title'] = $result->title;
		    $data['message'] = $result->message;
			$this->log->add( 'wannme', 'No se ha podido crear el cobro en WANNME para el carrito '.$data['id_cart'].'. Error: '.(int) json_encode($response['http_code']));
	    }

	    return $this->updateWannme($data);
	}

	public function updateWannme(Array $data = null)
	{
		global $wpdb;

		$toInsert = array();

		foreach ($data as $key => $value)
		{
			$toInsert[$key] = $value;
		}

		if ($data == null || !isset($data['id_wannme']))
		{
			$result = $wpdb->insert( 
			    $wpdb->prefix.'wannme', 
			    $toInsert
			);
		}
		else
		{
			$result = $wpdb->update( 
			    $wpdb->prefix.'wannme', 
			    $toInsert,
			    array('id_wannme' => $data['id_wannme'])
			);
		}
		
		if (!$result) {              
			$this->log->add( 'wannme', 'No se ha podido guardar el cobro en base de datos: '.$wpdb->last_query);
        }
		else
		{
			$this->log->add( 'wannme', 'Cobro guardado correctamente en base de datos');
		}

		return $wpdb->get_row( "SELECT * FROM ".$wpdb->prefix."wannme WHERE id_wannme = ".$wpdb->insert_id);
	}

	public function getChecksum($amount, $reference1)
	{
		return hash("sha512", WANNME_PARTNERID.WANNME_PRIVATEKEY.(string) $amount.(string) $reference1);
	}

	public function getPaymentMethods()
	{
	    $r = array(); 

	    if (WANNME_TYPES_FLOAPAY == 'yes') $r[] = 'floapay';
	    if (WANNME_TYPES_REDSYS == 'yes') $r[] = 'redsys';
	    if (WANNME_TYPES_REDSYS == 'yes') $r[] = 'cecabank';
	    if (WANNME_TYPES_BIZUM == 'yes') $r[] = 'bizum';
	    if (WANNME_TYPES_SLIMPAY_DIRECT_DEBIT == 'yes') $r[] = 'slimpay_direct_debit';
	    if (WANNME_TYPES_BANKTRANSFER == 'yes') $r[] = 'afterbanks';
	    if (WANNME_TYPES_BANKTRANSFER == 'yes') $r[] = 'yapily';
	    if (WANNME_TYPES_PAYPAL == 'yes') $r[] = 'paypal';
	    
	    return $r;
	}	
	
	private function include_payment_methods() {

		include_once 'includes/payment-methods/class-wc-gateway-wannme-floapay.php';
	}

	public function add_gateways( $gateways ) {
		
		$gateways[] = 'WC_Gateway_Wannme_Floapay';
		return $gateways;
	}	

	public function getWannmeByOrder(String $id_order)
	{
		global $wpdb;

		return $wpdb->get_row(
			$wpdb->prepare(
				"
				SELECT * 
				FROM {$wpdb->prefix}wannme
				WHERE id_cart = %s
				",
					$id_order
				)
			);
	}

	public function isPhoneNumber($number)
	{
	    return (bool) preg_match('/(\+34|0034|34)?[ -]*(6|7)[ -]*([0-9][ -]*){8}/', $number);
	}
}
