<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class WC_Gateway_Wannme_CreditCard extends wc_wannme {
	
	const PAYMENT_METHOD = array('redsys','cecabank');

	public function __construct() {
		
		$this->id = 'wc_wannme_cards';
		$this->method_title = __('WANNME - Cards', 'wc-wannme' );
		$this->method_description = __('Debit / Credit Card payments', 'wc-wannme' );
		$this->icon = apply_filters( 'woocommerce_gateway_icon', plugins_url( '../../assets/images/cards.png', __FILE__ ));
		$this->has_fields = false;
		$this->log =  new WC_Logger();
		
		$this->supports = array(
			'products'
		);		
		
		$this->init_form_fields();
		$this->init_settings();

		// Define user set variables
		$this->enabled = $this->get_option('enabled');
		$this->title = $this->get_option('title');
		$this->description = $this->get_option('description');
		$this->hide_text_box = $this->get_option('hide_text_box');
				
		$this->url = (WANNME_ENV == 0) ? WANNME_URL_DEV:WANNME_URL_PROD;
		
		add_filter('woocommerce_available_payment_gateways', array($this, 'wannme_update_payment_methods'));
		add_action('woocommerce_update_options_payment_gateways_'.$this->id, array($this, 'process_admin_options'));

		//Payment listener/API hook
        add_action( 'woocommerce_api_wc_wannme', array( $this, 'updateWnOrder' ) );

	}

	/**
	 * Initialise Settings Form Fields
	 * @return string|void
	 */
	public function init_form_fields() {
		$this->form_fields = array(
			'enabled'        => array(
				'title'   => __( 'Enable/Disable', 'wc-wannme' ),
				'type'    => 'checkbox',
				'label'   => __( 'Enable this payment method', 'wc-wannme' ),
				'default' => 'no'
			),
			'title'          => array(
				'title'       => __( 'Method Title', 'wc-wannme' ),
				'type'        => 'text',
				'description' => __( 'This text will be showed in the payment options. Please describe something user friendly (example: "Instant financing", "Pay or finance with WANNME").', 'wc-wannme' ),
				'default'     => __( 'Card Payment (Visa/Mastercard)', 'wc-wannme' )
			),
			'description'    => array(
				'title'       => __( 'Description', 'wc-wannme' ),
				'type'        => 'text',
				'description' => __( 'The message which you want it to appear to the customer in the checkout page.', 'wc-wannme' ),
				'default'     => __( 'Pay with my debit or credit card', 'wc-wannme' ),
			),
		);
	}
	
	public function process_payment( $order_id, $direct_payment_method = null ) {
		return parent::process_payment( $order_id, self::PAYMENT_METHOD );
	}
}

