<?php
/* @wordpress-plugin
 * Plugin Name:       WANNME Payment Gateway
 * Plugin URI:        https://www.wannme.com/
 * Description:       Ofrece una solución de pago con múltiples métodos de pago y financiación a través de la plataforma WANNME
 * Version:           3.0.5
 * Requires at least: 3.0
 * Tested up to: 6.4.2
 * WC requires at least: 3.0
 * WC tested up to: 8.5.2
 * Author:            WANNME Marketplace
 * Author URI:        https://www.wannme.com
 * Text Domain:       wc-wannme
 * Domain Path: /languages
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 */
 

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class WC_Wannme_Payment_Plugin {

	public static $plugin_version = '3.0.5';
	
	public function __construct() {
		
		$active_plugins = apply_filters('active_plugins', get_option('active_plugins'));

		
		if($this->wc_wannme_is_woocommerce_active()) {
				
			register_activation_hook( __FILE__, array( $this, 'install_wannme_plugin' )); //Activación
			
			// Actions
			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'plugin_action_links' ) );
			add_action( 'plugins_loaded', array( $this, 'init' ), 0 ); //Iniciamos el plugin
			//Añadir Menús
			add_action( 'admin_menu', array( $this, 'wannme_add_wordpress_menu' ));
			add_action('wc_wannme_detail', 'wc_wannme_detail' ); //Añadir página de detalle		
			//add_action('init', 'unregister_old_custom_order_statuses');
			//Añadimos estados de órdenes personalizados de Wannme: Deprecado para utilizar estados de Wordpress
			//add_action('init', 'register_custom_order_statuses');		
			
			
			add_filter('site_transient_update_plugins', array( $this, 'wannme_push_update' ) );
			add_filter('transient_update_plugins', array( $this, 'wannme_push_update' ) );
			add_filter('woocommerce_thankyou_order_received_text', array( $this, 'woo_change_order_received_text' ), 99, 2 );
			
			add_filter('woocommerce_payment_gateways', function( $gateways ) { //Añadir opción de pago en checkout
		
				$gateways[] = 'WC_Wannme';
				$gateways[] = 'WC_Gateway_Wannme_CreditCard';
				$gateways[] = 'WC_Gateway_Wannme_Bizum';
				$gateways[] = 'WC_Gateway_Wannme_Floapay';
				$gateways[] = 'WC_Gateway_Wannme_BankTransfer';
				$gateways[] = 'WC_Gateway_Wannme_SEPA_DirectDebit';
				$gateways[] = 'WC_Gateway_Wannme_Paypal';
				return $gateways; 
			});

		}
	}
	
	public function wc_wannme_is_woocommerce_active()
	{
		$active_plugins = (array) get_option('active_plugins', array());

		if (is_multisite()) {
			$active_plugins = array_merge($active_plugins, get_site_option('active_sitewide_plugins', array()));
		}

		return in_array('woocommerce/woocommerce.php', $active_plugins) || array_key_exists('woocommerce/woocommerce.php', $active_plugins);
	}	

	public function plugin_action_links( $links ) {
		$plugin_links = array(
			'<a href="' . admin_url( 'admin.php?page=wc-settings&tab=checkout&section=wc_wannme' ) . '">' . __( 'Settings', 'wc-wannme' ) . '</a>'
		);

		return array_merge( $plugin_links, $links );
	}
	
	public function init() {
		
		WC_Wannme_Payment_Plugin::wannme_update_db_check();
		
		require dirname( __FILE__ ) . '/class-wc-wannme.php';
		require dirname( __FILE__ ) . '/includes/payment-methods/class-wc-gateway-wannme-cards.php';
		require dirname( __FILE__ ) . '/includes/payment-methods/class-wc-gateway-wannme-bizum.php';
		require dirname( __FILE__ ) . '/includes/payment-methods/class-wc-gateway-wannme-floapay.php';
		require dirname( __FILE__ ) . '/includes/payment-methods/class-wc-gateway-wannme-banktransfer.php';
		require dirname( __FILE__ ) . '/includes/payment-methods/class-wc-gateway-wannme-sepadd.php';
		require dirname( __FILE__ ) . '/includes/payment-methods/class-wc-gateway-wannme-paypal.php';
		
		load_plugin_textdomain( "wc-wannme", false, dirname( plugin_basename( __FILE__ ) ). '/languages');
	}	
	
	public function wannme_update_db_check() {
		
		if ( version_compare( get_option( 'WANNME_VERSION', self::$plugin_version ), self::$plugin_version, '<' ) ) {
			WC_Wannme_Payment_Plugin::install_wannme_plugin();
		}
	}	
	
	//Instalación
	public function install_wannme_plugin()	{	
		
		global $wpdb;
		
		$table_name = $wpdb->prefix . 'wannme';
		$table_name_log = $wpdb->prefix . 'wannme_log';
		$charset_collate = "DEFAULT CHARACTER SET {$wpdb->charset} COLLATE {$wpdb->collate}";
		
		$sql = array();

		$sql[] = "CREATE TABLE {$table_name} (
			id_wannme int(11) NOT NULL AUTO_INCREMENT,
			id_cart int(10) unsigned NOT NULL,
			id_tracking text NOT NULL,
			amount decimal(20,6) DEFAULT '0.000000',
			description text,
			phone text,
			email text,
			reference1 text,
			reference2 text,
			document text,
			name text,
			lastname text,
			manualPayment tinyint(1) unsigned,
			sendEmail tinyint(1) unsigned,
			sendSMS tinyint(1) unsigned,
			url text,
			directlinks text,
			imageQR text,
			transactionCode int(10) unsigned,
			statusCode int(10) unsigned,
			statusDescription text,
			subStatusCode int(10) unsigned,
			subStatusDescription text,
			error int(10) unsigned,
			title text,
			message text,
			result text,
			PRIMARY KEY  (id_wannme)
		) {$charset_collate};";

		$sql[] = "CREATE TABLE {$table_name_log} (
			id_wannmelog int(11) NOT NULL AUTO_INCREMENT,
			value text,
			PRIMARY KEY  (id_wannmelog)
		) {$charset_collate};";
		
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		foreach ($sql as $query)
		{
			dbDelta($query);
		}
		
		update_option('WANNME_VERSION', self::$plugin_version); // Versión actual
	}

	public function wannme_add_wordpress_menu() {
		add_menu_page('WANNME', 'WANNME', 'edit_plugins', 'wc_wannme_list',  __CLASS__ . '::wc_wannme_list');
		add_submenu_page('wc_wannme_list', __( 'Transactions', 'wc-wannme' ), __( 'Transactions', 'wc-wannme' ), 'edit_plugins',  __CLASS__ . '::wc_wannme_list', 'wc_wannme_list');
		add_submenu_page('', __( 'Detail', 'wc-wannme' ), __( 'Detail', 'wc-wannme' ), 'edit_plugins', 'wc_wannme_detail',  __CLASS__ . '::wc_wannme_detail');
		add_submenu_page('', __( 'Confirm Refund', 'wc-wannme' ), __( 'Confirm Refund', 'wc-wannme' ), 'edit_plugins', 'wc_wannme_confirm_refund',  __CLASS__ . '::wc_wannme_confirm_refund');
		add_submenu_page('', __( 'Refund Completed', 'wc-wannme' ), __( 'Refund Completed', 'wc-wannme' ), 'edit_plugins', 'wc_wannme_refund',  __CLASS__ . '::wc_wannme_refund');		
	}
	
	
	public function wc_wannme_detail() {
		
		WC_Wannme_Payment_Plugin::wm_enqueue();

		$content = '';
		$content .= '
			<div class="row">
				<div class="col-md-12">
					<h1>'.__( 'WANNME transaction detail', 'wc-wannme' ).'</h1>
				</div>
			</div>
		';

		$id_wannme = $_GET['id_wannme'];
		$wannme = WC_Wannme_Payment_Plugin::getWannme($id_wannme);

		if ($wannme->error == 0)
		{
			$content .= "
				<div class='row'>
					<div class='col-md-12'>
						<a href='/wp-admin/admin.php?page=wc_wannme_confirm_refund&id_wannme=".$wannme->id_wannme."' class='btn btn-primary m-4 float-right'>
							<i class='icon-undo'></i>  ".__( 'Refund', 'wc-wannme' )."
						</a>
					</div>
				</div>";
		}			

		if ($wannme->error == 0)
		{
			$content .= "
			<div class='row'>
				<div class='col-md-12'>
					<table class='table'>
						<tbody>
							<tr>
								<td><strong>".__( 'ID', 'wc-wannme' )."</strong></td>
								<td>".$wannme->id_wannme."</td>
							</tr>
							<tr>
								<td><strong>".__( 'ID Wannme', 'wc-wannme' )."</strong></td>
								<td>".$wannme->id_tracking."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Order', 'wc-wannme' )."</strong></td>
								<td>".$wannme->id_cart." <a href='/wp-admin/post.php?post=".$wannme->id_cart."&action=edit' class='btn btn-primary btn-sm'> ".__( 'Go to Order', 'wc-wannme' )."</a>
								</td>
							</tr>
							<tr>
								<td><strong>".__( 'Total', 'wc-wannme' )."</strong></td>
								<td>".wc_price($wannme->amount)."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Description', 'wc-wannme' )."</strong></td>
								<td>".$wannme->description."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Reference 1', 'wc-wannme' )."</strong></td>
								<td>".$wannme->reference1."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Reference 2', 'wc-wannme' )."</strong></td>
								<td>".$wannme->reference2."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Transaction Code', 'wc-wannme' )."</strong></td>
								<td>".$wannme->transactionCode."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Status Code', 'wc-wannme' )."</strong></td>
								<td>".$wannme->statusCode."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Status Description', 'wc-wannme' )."</strong></td>
								<td>".$wannme->statusDescription."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Sub Status Code', 'wc-wannme' )."</strong></td>
								<td>".$wannme->subStatusCode."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Sub Status Description', 'wc-wannme' )."</strong></td>
								<td>".$wannme->subStatusDescription."</td>
							</tr>   
							<tr>
								<td><strong>".__( 'Document', 'wc-wannme' )."</strong></td>
								<td>".$wannme->document."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Name', 'wc-wannme' )."</strong></td>
								<td>".$wannme->name."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Lastname', 'wc-wannme' )."</strong></td>
								<td>".$wannme->lastname."</td>
							</tr> 
							<tr>
								<td><strong>".__( 'Phone', 'wc-wannme' )."</strong></td>
								<td>".$wannme->phone."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Email', 'wc-wannme' )."</strong></td>
								<td>".$wannme->email."</td>
							</tr>
						</tbody>
					</table>
				</div>
			</div>";
		}
		else
		{
			$content .= "
				<div class='row'>
					<div class='col-md-12'>
						<table class='table'>
							<tr>
								<td><strong>".__( 'ID', 'wc-wannme' )."</strong></td>
								<td>".$wannme->id_wannme."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Error', 'wc-wannme' )."</strong></td>
								<td>".$wannme->error."</td>
							</tr>
							<tr>
								<td><strong>".__( 'Message', 'wc-wannme' )."</strong></td>
								<td>".$wannme->message."</td>
							</tr>
						</table>
					</div>
				</div>";
		}

		$content .= "
			<div class='row'>
				<div class='col-md-12'>
					<div class='float-right'>
						<a href='/wp-admin/admin.php?page=wc_wannme_list' class='btn btn-primary m-4'>".__( 'Go Back', 'wc-wannme' )."
						</a>
					</div>
				</div>
			</div>";

		echo $content;
	}	
	
	public function unregister_old_custom_order_statuses() {

	}
	
	public function register_custom_order_statuses() {
		
		//WM = 1
		register_post_status('wc-wm-os-create', array(
			'label' => __( '[WANNME] Create', 'wc-wannme' ),
			'public' => false,
			'exclude_from_search' => false,
			'show_in_admin_all_list' => true,
			'show_in_admin_status_list' => true,
			'label_count' => _n_noop('Create <span class="count">(%s)</span>', 'Create <span class="count">(%s)</span>')
		));
		//WM = 3
		register_post_status('wc-wm-os-process', array(
			'label' => __( '[WANNME] In process', 'wc-wannme' ),
			'public' => false,
			'exclude_from_search' => false,
			'show_in_admin_all_list' => true,
			'show_in_admin_status_list' => true,
			'label_count' => _n_noop('In process <span class="count">(%s)</span>', 'In process <span class="count">(%s)</span>')
		));
		//WM = 4
		register_post_status('wc-wm-os-error', array(
			'label' => __( '[WANNME] Error', 'wc-wannme' ),
			'public' => false,
			'exclude_from_search' => false,
			'show_in_admin_all_list' => true,
			'show_in_admin_status_list' => true,
			'label_count' => _n_noop('Error <span class="count">(%s)</span>', 'Error <span class="count">(%s)</span>')
		));
		//WM = 5
		register_post_status('wc-wm-os-completed', array(
			'label' => __( '[WANNME] Completed', 'wc-wannme' ),
			'public' => false,
			'exclude_from_search' => false,
			'show_in_admin_all_list' => true,
			'show_in_admin_status_list' => true,
			'label_count' => _n_noop('Completed <span class="count">(%s)</span>', 'Completed <span class="count">(%s)</span>')
		));
		//WM = 8
		register_post_status('wc-wm-os-incomplete', array(
			'label' => __( '[WANNME] Incomplete', 'wc-wannme' ),
			'public' => false,
			'exclude_from_search' => false,
			'show_in_admin_all_list' => true,
			'show_in_admin_status_list' => true,
			'label_count' => _n_noop('Incomplete <span class="count">(%s)</span>', 'Incomplete <span class="count">(%s)</span>')
		));
		//WM = 9
		register_post_status('wc-wm-os-cancelled', array(
			'label' => __( '[WANNME] Cancelled', 'wc-wannme' ),
			'public' => false,
			'exclude_from_search' => false,
			'show_in_admin_all_list' => true,
			'show_in_admin_status_list' => true,
			'label_count' => _n_noop('Cancelled <span class="count">(%s)</span>', 'Cancelled <span class="count">(%s)</span>')
		));
		//WM = 10
		register_post_status('wc-wm-os-expired', array(
			'label' => __( '[WANNME] Expired', 'wc-wannme' ),
			'public' => false,
			'exclude_from_search' => false,
			'show_in_admin_all_list' => true,
			'show_in_admin_status_list' => true,
			'label_count' => _n_noop('Expired <span class="count">(%s)</span>', 'Expired <span class="count">(%s)</span>')
		));
		//WM = 13
		register_post_status('wc-wm-os-refundtotal', array(
			'label' => __( '[WANNME] Refund Total', 'wc-wannme' ),
			'public' => false,
			'exclude_from_search' => false,
			'show_in_admin_all_list' => true,
			'show_in_admin_status_list' => true,
			'label_count' => _n_noop('Refund Total <span class="count">(%s)</span>', 'Refund Total <span class="count">(%s)</span>')
		));
	}
	
	public function wannme_push_update( $transient ) {
		
		$class_wannme = new wc_wannme();
		//Llamar a la API para definir la versión
		$class_wannme->checkVersion();
		
		if ( version_compare( get_option( 'WANNME_LAST_VERSION', self::$plugin_version ), self::$plugin_version, '>' ) )
		{
			$res = new stdClass();
			$res->slug = 'wc_wannme';
			$res->plugin = 'wc_wannme/wc_wannme.php';
			$res->new_version = get_option('WANNME_LAST_VERSION');
			$res->package = get_option('WANNME_URL_UPDATE');
			$transient->response[$res->plugin] = $res;
		}

		return $transient;
	}
	
	
	public function getWannme(String $id)
	{
		global $wpdb;

		return $wpdb->get_row(
			$wpdb->prepare(
				"
				SELECT * 
				FROM {$wpdb->prefix}wannme
				WHERE id_wannme = %s
				",$id)
			);
	}
	
	public function refund($object)
	{
		global $wp_version;
		
		$class_wannme = new wc_wannme();

		$data = array(
			"checksum" => WC_Wannme_Payment_Plugin::getChecksumSimple($object->id_tracking),
			"partnerId" => $class_wannme->WANNME_PARTNERID
		);

		$options = array(
			CURLOPT_URL  => $class_wannme->url.'/wannmepay/payment/'.$object->id_tracking.'/action/total-refund',
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_ENCODING       => "",
			CURLOPT_MAXREDIRS      => 10,
			CURLOPT_TIMEOUT        => 0,
			CURLOPT_FOLLOWLOCATION => true,
			CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			CURLOPT_CUSTOMREQUEST  =>"POST",
			CURLOPT_POSTFIELDS => json_encode($data),            
			CURLOPT_HTTPHEADER => array(
				"Content-type: application/json; charset=UTF-8",
				"Authorization: ".$class_wannme->WANNME_SECRETKEY,
				"Wannme-Integration-Version: WordPress ".$wp_version." - WANNME ".get_option('WANNME_VERSION')
			)            
		);
		
		$ch = curl_init();
		curl_setopt_array( $ch, $options );
		$result = json_decode(curl_exec( $ch ));
		$response = curl_getinfo( $ch );
		curl_close( $ch );

		if (!property_exists ($result, 'code') || (int) json_encode($response['http_code']) <= 200)
		{
			return array(
				'status' => true
			);
		}
		else
		{
			return array(
				'status' => false,
				'code' => $result->code,
				'title' => $result->title,
				'message' => $result->message
			);
		}
	}
	
	
	public function wc_wannme_confirm_refund() {
		
		WC_Wannme_Payment_Plugin::wm_enqueue();

		$id_wannme = $_GET['id_wannme'];
		$wannme = WC_Wannme_Payment_Plugin::getWannme($id_wannme);

		$content = '';

		$content .= 
			"<div class='row'>
				<div class='col-md-12'>
					<h1>".__( 'WANNME return confirmation', 'wc-wannme' )."</h1>
				</div>
			</div>
			<div class='row'>
				<div class='col-md-6'>
					<div class='alert alert-danger' role='alert'>"
						.__( 'Please, Confirm total order refund.', 'wc-wannme' ).
						"<br><a href='/wp-admin/admin.php?page=wc_wannme_refund&id_wannme=".$wannme->id_wannme."' class='btn btn-danger m-4'>"
						.__( 'Confirm Refund', 'wc-wannme' ).
						"</a>
					</div>
				</div>
			</div>";

		echo $content;
	}	
	
	
	public function wc_wannme_refund() {
		
		WC_Wannme_Payment_Plugin::wm_enqueue();

		$id_wannme = $_GET['id_wannme'];
		$wmtracking = WC_Wannme_Payment_Plugin::getWannme($id_wannme);

		$result = WC_Wannme_Payment_Plugin::refund($wmtracking);

		$content = '';

		//Refund OK
		if ($result['status'] == true)
		{
			$content .= 
				"<div class='row'>
					<div class='col-md-12'>
						<h1>".__( 'WANNME return completed successfully', 'wc-wannme' )."</h1>
					</div>
				</div>
				<div class='row'>
					<div class='col-md-12'>
						<div class='alert alert-success' role='alert'>
							<p>".__( 'The return has been completed successfully', 'wc-wannme' )."</p>
						</div>
					</div>
				</div>";
		}
		//Refund KO
		else
		{
			$content .= 
				"<div class='row'>
					<div class='col-md-12'>
						<h1>".__( 'Error when making the return', 'wc-wannme' )."</h1>
					</div>
				</div>
				<div class='row'>
					<div class='col-md-12'>
						<div class='alert alert-danger' role='alert'>
							<p><strong>".__( 'The return could not be completed, consult Technical Support.', 'wc-wannme' )."</strong></p>
							<p>".__( 'Error: '.$result['code'].' The return could not be completed, consult Technical Support. '.$result['title'].' '.$result['message'], 'wc-wannme' )."</p>
						</div>
					</div>
				</div>";
		}

		echo $content;
	}	
	
	public function getChecksumSimple($id) {
		
		$class_wannme = new wc_wannme();

		return sha1($class_wannme->WANNME_PARTNERID.$class_wannme->WANNME_PRIVATEKEY.(string) $id);
	}

	public function wc_wannme_list() {
		
		WC_Wannme_Payment_Plugin::wm_enqueue();

		global $wpdb;
		$rows = $wpdb->get_results( 
			"
				SELECT * 
				FROM {$wpdb->prefix}wannme
			"
		);

		$content = '';

		$content .= '
			<div class="row">
				<div class="col-md-12">
					<h1>'.__( 'WANNME transaction listing', 'wc-wannme' ).'</h1>
				</div>
			</div>
		';

		$content .= "";

		$content .=
			'<div class="row">
				<div class="col-md-12">
					<table class="wp-list-table widefat fixed striped table-view-list posts">
				<thead>	
					<tr>
						<th scope="col" class="manage-column column-primary">'.__( 'ID', 'wc-wannme' ).'</th>
						<th scope="col" class="manage-column">'.__( 'ID Wannme', 'wc-wannme' ).'</th>
						<th scope="col" class="manage-column">'.__( 'ID Cart', 'wc-wannme' ).'</th>
						<th scope="col" class="manage-column">'.__( 'Name', 'wc-wannme' ).'</th>
						<th scope="col" class="manage-column">'.__( 'Lastname', 'wc-wannme' ).'</th>
						<th scope="col" class="manage-column">'.__( 'Total', 'wc-wannme' ).'</th>
						<th scope="col" class="manage-column">'.__( 'Phone', 'wc-wannme' ).'</th>
						<th scope="col" class="manage-column">'.__( 'Email', 'wc-wannme' ).'</th>
						<th scope="col" class="manage-column">'.__( 'Ref 1', 'wc-wannme' ).'</th>
						<th scope="col" class="manage-column">'.__( 'Ref 2', 'wc-wannme' ).'</th>
						<th scope="col" class="manage-column">'.__( 'Status', 'wc-wannme' ).'</th>
						<th scope="col" class="manage-column">'.__( 'SubStatus', 'wc-wannme' ).'</th>
						<th scope="col" class="manage-column"></th>
					</tr>
				</thead>
				<tbody id="the-list">';

				foreach ($rows as $row)
				{
					$content .= 
					'<tr class="iedit author-self level-0 type-shop_order status-wc-pending">'
						.'<td class="order_number column-primary"><strong>'.$row->id_wannme.'</strong></td>'
						.'<td class="order_number"><strong><a href="/wp-admin/admin.php?page=wc_wannme_detail&id_wannme='.$row->id_wannme.'" title='.__( "Edit", "wc-wannme" ).'>'.$row->id_tracking.'</strong></a></td>'
						.'<td class="order_number"><strong>'.$row->id_cart.'</strong></td>'
						.'<td>'.$row->name.'</td>'
						.'<td>'.$row->lastname.'</td>'
						.'<td>'.wc_price($row->amount).'</td>'
						.'<td>'.$row->phone.'</td>'
						.'<td>'.$row->email.'</td>'
						.'<td>'.$row->reference1.'</td>'
						.'<td>'.$row->reference2.'</td>'
						.'<td>'.$row->statusDescription.'</td>'
						.'<td>'.$row->subStatusDescription.'</td>'
						.'<td><a href="/wp-admin/admin.php?page=wc_wannme_detail&id_wannme='.$row->id_wannme.'" title='.__( "Edit", "wc-wannme" ).'>'.__( "Edit", "wc-wannme" ).'</a></td>'
					.'</tr>';
				}
					
		$content .=
						'</tbody>
					</table>
				</div>
			</div>';

		echo $content;
	}
	
	public function woo_change_order_received_text( $str, $order ) {
		
		$class_wannme = new wc_wannme();

		$wm = $class_wannme->getWannmeByOrder($order->get_id());
		$new_str =
			'<li class="woocommerce-order-overview__order order">
				'.__( 'WANNME Tracking', 'wc-wannme' ).'
				<strong>'.$wm->id_tracking.'</strong>
			</li>';

		return $str;
	}	
	
	public function wm_enqueue() {
		
		// JS
		wp_register_script('wm_jquery', 'https://code.jquery.com/jquery-3.5.1.slim.min.js');
		wp_register_script('wm_bootstrap', 'https://cdn.jsdelivr.net/npm/bootstrap@4.5.3/dist/js/bootstrap.bundle.min.js');
	   
		wp_enqueue_script('wm_jquery');
		wp_enqueue_script('wm_bootstrap');

		// CSS
		wp_register_style('wm_bootstrap', 'https://cdn.jsdelivr.net/npm/bootstrap@4.5.3/dist/css/bootstrap.min.css');
		wp_enqueue_style('wm_bootstrap');
        

	}	
	
}	

new WC_Wannme_Payment_Plugin();	
